==> enterprisemodules-ora_install-5.11.2.tar.gz: enterprisemodules-ora_install-5.11.2/lib/puppet/type/ora_home.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
require 'pathname'
current_path = Pathname.new(__FILE__).dirname
$LOAD_PATH.unshift(current_path.parent.parent)
$LOAD_PATH.unshift(current_path.parent.parent.parent.parent + 'easy_type' + 'lib')
require 'easy_type'
require 'puppet_x/enterprisemodules/ora_install/core'
require 'fileutils'
require 'rexml/document'

module Puppet
  def module_name
    'ora_install'
  end
#
  Type.newtype(:ora_home) do
    include EasyType
    include EasyType::Helpers
    include PuppetX::EnterpriseModules::OraInstall::Commands
    include PuppetX::EnterpriseModules::OraInstall::GetHomes
    include PuppetX::EnterpriseModules::OraInstall::Facts

    desc 'This resource allows you to manage Oracle homes.'

    def self.registered_homes
      homes = []
      begin
        doc = REXML::Document.new(inventory_content)
        doc.each_element('/INVENTORY/HOME_LIST/HOME') do |e|
          homes << {:name => e.attribute('NAME').value, :location => e.attribute('LOC').value}
        end
      rescue Errno::ENOENT
        # Do nothing Some of the files not found means no valid Inventory
      end
      homes
    end

    def self.inventory_content
      File.read(inventory_path)
    end

    def self.inventory_path
      "#{inventory_loc}/ContentsXML/inventory.xml"
    end

    def self.inst_group
      content_for('inst_group')
    end

    def self.inventory_loc
      content_for('inventory_loc')
    end

    def self.content_for(variable)
      orainst_loc_content.match(/#{variable}=(.*)/)[1]
    end

    def self.orainst_loc_content
      File.read("/etc/oraInst.loc")
    end


    to_get_raw_resources do
      registered_homes
    end

    on_create do
      parameters[:source].process # The source property fetches and unpacks the zip or tar file
      clean_admin_files
      clone_dir
      run_root_script
    end

    on_modify do
      fail 'Modification is not supported'
    end

    on_destroy do
      check_running_processes_on(provider.location)
      delete_files
      delete_inventory_entry
    end

    def refresh
    end

    def check_running_processes_on(location)
      sids = get_running_sids(location)
      fail "Cannot remove Oracle home #{name}; Oracle sid(s) #{sids.join(',')} running from #{provider}." unless sids.empty?
      fail "Cannot remove Oracle home #{name}; Still processes running from #{provider}." if `ps -eaf | grep #{location}`
    end
    #
    # Delete the entry from the inventory
    #
    def delete_inventory_entry
      doc = REXML::Document.new(self.class.inventory_content)
      doc.root.delete_element("/INVENTORY/HOME_LIST/HOME[@NAME='#{name}']")
      formatter = REXML::Formatters::Default.new
      new_content = formatter.write(doc.root, '')
      File.write(self.class.inventory_path, new_content)
    end

    # Remove all files in the home path
    def delete_files
      Puppet.debug Puppet::Util::Execution.execute("rm -rf #{provider.location}")
    end

    def clean_admin_files
      Puppet.debug Puppet::Util::Execution.execute("rm -rf #{location}/network/admin/*.ora")
    end

    def clone_dir
      fail "#{location}/perl/bin/perl not found." unless File.exists?("#{location}/perl/bin/perl")
      fail "#{location}/clone/bin/clone.pl not found." unless File.exists?("#{location}/clone/bin/clone.pl")
      if grid == :true
        command = "#{location}/perl/bin/perl #{location}/clone/bin/clone.pl ORACLE_BASE=\"#{oracle_base}\" ORACLE_HOME=\"#{location}\" OSASM_GROUP=#{asm_group} OSOPER_GROUP=#{oper_group} ORACLE_HOME_NAME=#{name}"
      else
        command = "#{location}/perl/bin/perl #{location}/clone/bin/clone.pl ORACLE_BASE=\"#{oracle_base}\" ORACLE_HOME=\"#{location}\" OSDBA_GROUP=#{dba_group} OSOPER_GROUP=#{oper_group} ORACLE_HOME_NAME=#{name}"
      end
      output = Puppet::Util::Execution.execute(command, :uid => user, :failonfail => true)
      Puppet.debug output
    end

    def run_root_script
      command = "#{location}/root.sh"
      fail "#{command} not found." unless File.exists?(command)
      output = Puppet::Util::Execution.execute(command, :failonfail => true)
      Puppet.debug output
    end

    validate do
      if self[:ensure] == :present
        fail "Location '#{location}' needs to below Oracle base '#{oracle_base}'" if !location.include?(oracle_base)
        fail "Oracle base '#{oracle_base}' needs to exist before activating ora_home." if !File.directory?(oracle_base) 
      end
    end

    ensurable

    parameter :name

    parameter :oracle_base
    parameter :user
    parameter :grid
    parameter :dba_group
    parameter :asm_group
    parameter :oper_group
    parameter :source
    parameter :tmp_dir

    property  :location
  end

end

==> enterprisemodules-ora_install-5.14.3.tar.gz: enterprisemodules-ora_install-5.14.3/lib/puppet/type/ora_home.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
require 'pathname'
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../.."))
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../../../../easy_type/lib"))
require 'easy_type'
require 'puppet_x/enterprisemodules/ora_install/core'
require 'fileutils'
require 'rexml/document'

module Puppet
  def module_name
    'ora_install'
  end
#
  Type.newtype(:ora_home) do
    include EasyType
    include EasyType::Helpers
    include PuppetX::EnterpriseModules::OraInstall::Commands
    include PuppetX::EnterpriseModules::OraInstall::GetHomes
    include PuppetX::EnterpriseModules::OraInstall::Facts

    desc 'This resource allows you to manage Oracle homes.'

    def self.registered_homes
      homes = []
      begin
        doc = REXML::Document.new(inventory_content)
        doc.each_element('/INVENTORY/HOME_LIST/HOME') do |e|
          homes << {:name => e.attribute('NAME').value, :location => e.attribute('LOC').value}
        end
      rescue Errno::ENOENT
        # Do nothing Some of the files not found means no valid Inventory
      end
      homes
    end

    def self.inventory_content
      File.read(inventory_path)
    end

    def self.inventory_path
      "#{inventory_loc}/ContentsXML/inventory.xml"
    end

    def self.inst_group
      content_for('inst_group')
    end

    def self.inventory_loc
      content_for('inventory_loc')
    end

    def self.content_for(variable)
      orainst_loc_content.match(/#{variable}=(.*)/)[1]
    end

    def self.orainst_loc_content
      File.read("/etc/oraInst.loc")
    end


    to_get_raw_resources do
      registered_homes
    end

    on_create do
      parameters[:source].process # The source property fetches and unpacks the zip or tar file
      clean_admin_files
      clone_dir
      run_root_script
    end

    on_modify do
      fail 'Modification is not supported'
    end

    on_destroy do
      check_running_processes_on(provider.location)
      delete_files
      delete_inventory_entry
    end

    def refresh
    end

    def check_running_processes_on(location)
      sids = get_running_sids(location).keys
      fail "Cannot remove Oracle home #{name}; Oracle sid(s) #{sids.join(',')} running from #{provider}." unless sids.empty?
      fail "Cannot remove Oracle home #{name}; Still processes running from #{provider}." if `ps -eaf | grep #{location}`
    end
    #
    # Delete the entry from the inventory
    #
    def delete_inventory_entry
      doc = REXML::Document.new(self.class.inventory_content)
      doc.root.delete_element("/INVENTORY/HOME_LIST/HOME[@NAME='#{name}']")
      formatter = REXML::Formatters::Default.new
      new_content = formatter.write(doc.root, '')
      File.write(self.class.inventory_path, new_content)
    end

    # Remove all files in the home path
    def delete_files
      Puppet.debug Puppet::Util::Execution.execute("rm -rf #{provider.location}")
    end

    def clean_admin_files
      Puppet.debug Puppet::Util::Execution.execute("rm -rf #{location}/network/admin/*.ora")
    end

    def clone_dir
      fail "#{location}/perl/bin/perl not found." unless File.exists?("#{location}/perl/bin/perl")
      fail "#{location}/clone/bin/clone.pl not found." unless File.exists?("#{location}/clone/bin/clone.pl")
      if grid == :true
        command = "#{location}/perl/bin/perl #{location}/clone/bin/clone.pl ORACLE_BASE=\"#{oracle_base}\" ORACLE_HOME=\"#{location}\" OSASM_GROUP=#{asm_group} OSOPER_GROUP=#{oper_group} ORACLE_HOME_NAME=#{name}"
      else
        command = "#{location}/perl/bin/perl #{location}/clone/bin/clone.pl ORACLE_BASE=\"#{oracle_base}\" ORACLE_HOME=\"#{location}\" OSDBA_GROUP=#{dba_group} OSOPER_GROUP=#{oper_group} ORACLE_HOME_NAME=#{name}"
      end
      output = Puppet::Util::Execution.execute(command, :uid => user, :failonfail => true)
      Puppet.debug output
    end

    def run_root_script
      command = "#{location}/root.sh"
      fail "#{command} not found." unless File.exists?(command)
      output = Puppet::Util::Execution.execute(command, :failonfail => true)
      Puppet.debug output
    end

    validate do
      if self[:ensure] == :present
        fail "Location '#{location}' needs to below Oracle base '#{oracle_base}'" if !location.include?(oracle_base)
        fail "Oracle base '#{oracle_base}' needs to exist before activating ora_home." if !File.directory?(oracle_base) 
      end
    end

    ensurable

    parameter :name

    parameter :oracle_base
    parameter :user
    parameter :grid
    parameter :dba_group
    parameter :asm_group
    parameter :oper_group
    parameter :source
    parameter :tmp_dir

    property  :location
  end

end
